@@ -2,6 +2,7 @@ from dotdict import DotDict
 from jinja2 import PackageLoader
 import sys
 import os
+from pkg_resources import iter_entry_points
 
 
 # Frame's library path
@@ -10,62 +11,34 @@ __app_name = sys.argv[0]
 
 
 config = DotDict({
-	'sessions': {
-		'driver': 'memory',
-		'cookie_name': 'FrameSession',
-		'expires': 168,
-		'cleanup_frequency': 30,
-		'enabled': True,
-		
-		'memcache': {
-			'prefix': 'FRAME_SESSION::',
-			'connection': None,
-			'servers': ['127.0.0.1:11211'],
-		},
-		
-		'memory': {
-		},
-		'file': {
-			'directory': 'sessions',
-		},
-		'mysql': {
-			'host': 'localhost',
-			'port': 3306,
-			'connection': None,
-			'database': None,
-			'user': None,
-			'password': None,
-			'table': 'frame_sessions'
-		}
-	},
-	
-	'orm': {
-		'driver': None
-	},
-	
 	'application': {
 		'name': 'Frame (%s)' % __app_name,
-		'strip_trailing_slash': True
+		'strip_trailing_slash': True,
+		'dispatcher': 'routes',
+		'debug': False,
 	},
 	
 	'templates': {
 		'directory': 'templates',
 		'loaders': [PackageLoader('frame', 'templates')],
-		'globals': {}
+		'globals': {},
+		'filters': {}
 	},
 	
-	'pre_processors': [
+	'preprocessors': [
 		'handle_query_string',
 		'form_url_decoder',
 		'form_json_decoder',
 		'form_multipart_decoder',
 	],
 	
-	'post_processors': [
+	'postprocessors': [
 		'handle_head_request',
 		'add_last_modified'
 	],
 	
+	'hooks': [],
+	
 	'timezone': 'America/Los_Angeles',
 	
 	'logger': {
@@ -92,11 +65,23 @@ config = DotDict({
 		'version': '0.1a',
 	},
 	
+	'http_server': {
+		'num_workers': 10,
+	},
+	
 	'response': {
 		'default_headers': {
-			'Connection': 'close',
 			'Content-Type': 'text/html',
 			'Server': 'Frame/0.1a',
 		}
 	}
-})
\ No newline at end of file
+})
+
+
+if __name__ == '__main__':
+	for entry_point in iter_entry_points('frame.config'):
+		register_config = entry_point.load()
+		register_config(config)
+
+	config.prettify()
+
